#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const device_esp32c3_js_1 = require("../device-esp32c3.js");
const logger_js_1 = require("../logger.js");
const node_specific_js_1 = require("../node-specific.js");
const serial = new node_specific_js_1.SerialPort("/dev/cu.usbmodem101");
const enableTrace = (process.argv.indexOf("--trace") >= 0);
(async function () {
    const logger = (enableTrace ? logger_js_1.Logger.logger() : logger_js_1.Logger.voidLogger());
    const device = new device_esp32c3_js_1.DeviceEsp32c3(serial, { logger });
    await device.connect();
    const deviceInfo = await device.getDeviceInfo();
    const macAddress = await device.getMacAddress();
    console.log("Device Info:");
    console.log(`  Description: ${deviceInfo.description}`);
    console.log(`  MAC Address: ${macAddress}`);
})().catch((error) => {
    console.log("Error:", error.message);
    console.log(error);
});
//# sourceMappingURL=firefly.js.map