import { Logger } from "./logger.js";
import type { SerialPort } from "./serial.js";
export declare const Sequences: Record<string, string>;
export interface DeviceOptions {
    maxReadBuffer?: number;
    maxWriteBuffer?: number;
    logger?: Logger;
}
export declare class Device {
    #private;
    readonly serial: SerialPort;
    readonly logger: Logger;
    constructor(serial: SerialPort, options?: DeviceOptions);
    get maxReadBuffer(): number;
    get maxWriteBuffer(): number;
    get available(): number;
    get backlog(): number;
    /**
     *  Reads any data on the stream into the read buffer and returns
     *  the combined data.
     *
     *  Use [[_unread]] to place any data back on the read buffer
     *  to be processed in the future.
     */
    read(): Promise<Uint8Array>;
    /**
     *  Read a SLIP packet, optionally matching the %%op%%. Returns
     *  ``null`` if no complete matching packet is found.
     *
     *  Any stray packets or bytes at the front of the read buffer
     *  are discarded.
     */
    readSlipPacket(op?: number): Promise<null | {
        value: number;
        data: Uint8Array;
    }>;
    _unread(data: Uint8Array): void;
    write(data: Uint8Array): Promise<boolean>;
    writeSlipPacket(data: Uint8Array): Promise<boolean>;
    /**
     *  Reset the connected device, optionally providing a reset
     *  %%sequence%% for fine control over the DTR/RTS signals.
     */
    reset(sequence?: string): Promise<void>;
    /**
     *  Send a command to the connected device and parse the response.
     */
    command(op: number, data?: Array<number> | Uint8Array, checksum?: number): Promise<any>;
    readRegister(address: number): Promise<number>;
    sync(): Promise<any>;
}
//# sourceMappingURL=device.d.ts.map