"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
const utils_js_1 = require("./utils.js");
function pad(c, length) {
    while (c.length < length) {
        c += c;
    }
    return c.substring(0, length);
}
class Logger {
    printer;
    #indent;
    constructor(printer) {
        this.printer = printer || console.log;
        this.#indent = 0;
    }
    get indent() { return this.#indent; }
    data(data, title) {
        if (title == null) {
            title = "[DATA]";
        }
        if (title) {
            title += " ";
        }
        this._print(`${title}${data.length} bytes`);
        for (let i = 0; i < data.length; i += 16) {
            const chunk = data.slice(i, i + 16);
            let line = "  " + (0, utils_js_1.hexlify)(chunk.slice(0, 8)) + " " + (0, utils_js_1.hexlify)(chunk.slice(8));
            line += pad(" ", 37 - line.length) + "|  ";
            for (let j = 0; j < chunk.length; j++) {
                const c = chunk[j];
                if (c >= 32 && c <= 127) {
                    line += String.fromCharCode(c);
                }
                else {
                    line += ".";
                }
            }
            this._print(line);
        }
    }
    info(message) {
        this._print(message);
    }
    object(obj, title) {
        if (title == null) {
            title = "[DATA]";
        }
        if (title) {
            title += " ";
        }
        this._print(`${title}${JSON.stringify(obj)}`);
    }
    _print(message) {
        if (message.startsWith("<<|")) {
            message = message.substring(3).trim();
            this.#indent--;
        }
        let indent = message.startsWith("|>>");
        if (indent) {
            message = message.substring(3).trim();
        }
        this.printer(pad(" ", this.#indent * 2) + message);
        if (indent) {
            this.#indent++;
        }
    }
    static voidLogger() {
        return new Logger((l) => { });
    }
    static logger() {
        return new Logger();
    }
}
exports.Logger = Logger;
//# sourceMappingURL=logger.js.map