"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SerialPort = void 0;
const fs_1 = __importDefault(require("fs"));
const ioctl_1 = __importDefault(require("ioctl"));
const serial_js_1 = require("./serial.js");
const utils_js_1 = require("./utils.js");
const TIOCMGET = 0x4004746a, TIOCMSET = 0x8004746d;
const TIOCM_RTS = 4, TIOCM_DTR = 2;
class SerialPort extends serial_js_1.SerialPort {
    filename;
    #fd;
    constructor(filename) {
        super();
        this.filename = filename;
        this.#fd = fs_1.default.openSync(filename, fs_1.default.constants.O_RDWR | fs_1.default.constants.O_NONBLOCK);
    }
    async read() {
        const chunks = [];
        let length = 0;
        while (true) {
            try {
                const buffer = new Uint8Array(1024);
                const l = fs_1.default.readSync(this.#fd, buffer);
                chunks.push(buffer.slice(0, l));
                length += l;
                await (0, utils_js_1.stall)(50);
            }
            catch (e) {
                if (e.code !== "EAGAIN") {
                    console.log("ERROR READ", e);
                    throw e;
                }
                break;
            }
        }
        return (0, utils_js_1.concat)(chunks);
    }
    async getSignal() {
        const result = Buffer.from([0]);
        (0, ioctl_1.default)(this.#fd, TIOCMGET, result);
        return {
            dtr: !!(result[0] & TIOCM_DTR),
            rts: !!(result[0] & TIOCM_RTS),
        };
    }
    async signal(signal) {
        const arg = Buffer.from([0]);
        if (signal.dtr) {
            arg[0] |= TIOCM_DTR;
        }
        if (signal.rts) {
            arg[0] |= TIOCM_RTS;
        }
        (0, ioctl_1.default)(this.#fd, TIOCMSET, arg);
    }
    async write(data) {
        fs_1.default.writeSync(this.#fd, data);
        return true;
    }
}
exports.SerialPort = SerialPort;
/*
const decoder = new TextDecoder();


const serial = new SerialPort("/dev/cu.usbmodem1101");
serial.addListener("data", (data: Uint8Array) => {
    console.log("DATA", decoder.decode(data));
});

import { chipName } from "./chips.js";

(async function() {
    await serial.reset();
    await stall(50);
    await serial.read();

    await serial.sync();
    await stall(100);
    await serial.read();

    const result = await serial.readRegister(0x40001000);
    console.log("CHIP", chipName(result));
    await serial.read();

})();
*/
//# sourceMappingURL=node-specific.js.map