"use strict";
////////////////////////////////////////
// Errors
Object.defineProperty(exports, "__esModule", { value: true });
exports.stall = exports.toLeBytes = exports.fromLeBytes = exports.hexlify = exports.concat = exports.assert = void 0;
function assert(cond, message, info) {
    if (cond) {
        return;
    }
    const error = new Error(message);
    if (info) {
        for (const key in info) {
            error[key] = info[key];
        }
    }
    throw error;
}
exports.assert = assert;
////////////////////////////////////////
// Data manipulation
function concat(datas) {
    const length = datas.reduce((a, d) => (a + d.length), 0);
    const result = new Uint8Array(length);
    let offset = 0;
    for (const data of datas) {
        result.set(data, offset);
        offset += data.length;
    }
    return result;
}
exports.concat = concat;
const HEX = "0123456789abcdef";
function hexlify(value, width) {
    let result = "";
    if (typeof (value) === "number") {
        result = value.toString(16);
    }
    else {
        for (let i = 0; i < value.length; i++) {
            const d = value[i];
            result += HEX[d >> 4] + HEX[d & 0x0f];
        }
    }
    if (typeof (width) === "number") {
        while (result.length < 2 * width) {
            result = "0" + result;
        }
    }
    else if (width) {
        if (result.length % 2) {
            result = "0" + result;
        }
    }
    return result;
}
exports.hexlify = hexlify;
function fromLeBytes(bytes) {
    let result = 0;
    for (let i = 0; i < bytes.length; i++) {
        result |= (bytes[i] << (i << 3));
    }
    return result;
}
exports.fromLeBytes = fromLeBytes;
function toLeBytes(value, width) {
    const result = new Uint8Array(width);
    for (let i = 0; i < width; i++) {
        result[i] = value & 0xff;
        value >>= 8;
    }
    return result;
}
exports.toLeBytes = toLeBytes;
////////////////////////////////////////
// Promisification
function stall(duration) {
    return new Promise((resolve) => {
        setTimeout(resolve, duration);
    });
}
exports.stall = stall;
//# sourceMappingURL=utils.js.map