////////////////////////////////////////
// Errors
export function assert(cond, message, info) {
    if (cond) {
        return;
    }
    const error = new Error(message);
    if (info) {
        for (const key in info) {
            error[key] = info[key];
        }
    }
    throw error;
}
////////////////////////////////////////
// Data manipulation
export function concat(datas) {
    const length = datas.reduce((a, d) => (a + d.length), 0);
    const result = new Uint8Array(length);
    let offset = 0;
    for (const data of datas) {
        result.set(data, offset);
        offset += data.length;
    }
    return result;
}
const HEX = "0123456789abcdef";
export function hexlify(value, width) {
    let result = "";
    if (typeof (value) === "number") {
        result = value.toString(16);
    }
    else {
        for (let i = 0; i < value.length; i++) {
            const d = value[i];
            result += HEX[d >> 4] + HEX[d & 0x0f];
        }
    }
    if (typeof (width) === "number") {
        while (result.length < 2 * width) {
            result = "0" + result;
        }
    }
    else if (width) {
        if (result.length % 2) {
            result = "0" + result;
        }
    }
    return result;
}
export function fromLeBytes(bytes) {
    let result = 0;
    for (let i = 0; i < bytes.length; i++) {
        result |= (bytes[i] << (i << 3));
    }
    return result;
}
export function toLeBytes(value, width) {
    const result = new Uint8Array(width);
    for (let i = 0; i < width; i++) {
        result[i] = value & 0xff;
        value >>= 8;
    }
    return result;
}
////////////////////////////////////////
// Promisification
export function stall(duration) {
    return new Promise((resolve) => {
        setTimeout(resolve, duration);
    });
}
//# sourceMappingURL=utils.js.map