
////////////////////////////////////////
// Errors

export function assert(cond: any, message: string, info?: Record<string, any>): asserts cond {
    if (cond) { return; }
    const error: any = new Error(message);
    if (info) {
        for (const key in info) { error[key] = info[key]; }
    }
    throw error;
}

////////////////////////////////////////
// Data manipulation

export function concat(datas: Array<Uint8Array>): Uint8Array {
    const length = datas.reduce((a, d) => (a + d.length), 0);

    const result = new Uint8Array(length);

    let offset = 0;
    for (const data of datas) {
        result.set(data, offset);
        offset += data.length;
    }

    return result;
}

const HEX = "0123456789abcdef";

export function hexlify(value: number | Uint8Array, width?: boolean | number): string {

    let result = "";

    if (typeof(value) === "number") {
        result = value.toString(16);
    } else {
        for (let i = 0; i < value.length; i++) {
            const d = value[i];
            result += HEX[d >> 4] + HEX[d & 0x0f];
        }
    }

    if (typeof(width) === "number") {
        while (result.length < 2 * width) { result = "0" + result; }
    } else if (width) {
        if (result.length % 2) { result = "0" + result; }
    }

    return result;
}

export function fromLeBytes(bytes: Array<number> | Uint8Array): number {
    let result = 0;
    for (let i = 0; i < bytes.length; i++) {
        result |= (bytes[i] << (i << 3));
    }
    return result;
}

export function toLeBytes(value: number, width: number): Uint8Array {
    const result = new Uint8Array(width);
    for (let i = 0; i < width; i++) {
        result[i] = value & 0xff;
        value >>= 8;
    }
    return result;
}


////////////////////////////////////////
// Promisification

export function stall(duration: number): Promise<void> {
    return new Promise((resolve) => {
        setTimeout(resolve, duration);
    });
}

